


channels_detailed =  ['acu.message_counter',
 'acu.actual_timestamp',
 'acu.general_management_and_controller.ds_software_version',
 'acu.general_management_and_controller.state',
 'acu.general_management_and_controller.bit_status.low_power_mode_activ',

 'acu.general_management_and_controller.bit_status.hhd_connected',
 'acu.general_management_and_controller.bit_status.on_source',

 'acu.general_management_and_controller.error_status.az_error',
 'acu.general_management_and_controller.error_status.el_error',
 'acu.general_management_and_controller.error_status.fi_error',
 'acu.general_management_and_controller.error_status.stp_error',
 'acu.general_management_and_controller.error_status.saf_error',
 'acu.general_management_and_controller.error_status.tim_error',
 'acu.general_management_and_controller.error_status.cmd_error',
 'acu.general_management_and_controller.error_status.pwr_error',
 'acu.general_management_and_controller.warning_status.trx_warning',
 'acu.general_management_and_controller.warning_status.poi_warning',
 'acu.general_management_and_controller.warning_status.dmc_warning',
 'acu.general_management_and_controller.warning_status.az_warning',
 'acu.general_management_and_controller.warning_status.el_warning',
 'acu.general_management_and_controller.warning_status.fi_warning',
 'acu.general_management_and_controller.warning_status.stp_warning',
 'acu.general_management_and_controller.warning_status.saf_warning',
 'acu.general_management_and_controller.warning_status.tim_warning',
 'acu.general_management_and_controller.warning_status.cmd_warning',
 'acu.general_management_and_controller.warning_status.pwr_warning',
 'acu.general_management_and_controller.warning_status.horn_on',
 'acu.general_management_and_controller.warning_status.safe_2_approach_light_on',
 'acu.general_management_and_controller.p_set_az',
 'acu.general_management_and_controller.p_act_az',
 'acu.general_management_and_controller.v_act_az',
 'acu.general_management_and_controller.p_point_corr_az',
 'acu.general_management_and_controller.p_set_el',
 'acu.general_management_and_controller.p_act_el',
 'acu.general_management_and_controller.v_act_el',
 'acu.general_management_and_controller.p_point_corr_el',
 'acu.general_management_and_controller.feed_indexer_pos',
 'acu.general_management_and_controller.on_source_deviation_rms',
 'acu.general_management_and_controller.power_status_bs.cb_chain_pdu_psc',
 'acu.general_management_and_controller.power_status_bs.cb_chain_pdu_ped',
 'acu.general_management_and_controller.power_status_bs.cb_chain_pdu_fi',
 'acu.general_management_and_controller.temp_azimuth_i_o_unit',
 'acu.general_management_and_controller.hum_azimuth_i_o_unit',
 'acu.general_management_and_controller.temp_elevation_i_o_unit',
 'acu.general_management_and_controller.hum_elevation_i_o_unit',
 'acu.general_management_and_controller.temp_feedindexer_i_o_unit',
 'acu.general_management_and_controller.hum_feedindexer_i_o_unit',
 'acu.general_management_and_controller.temp_emisc',
 'acu.general_management_and_controller.temp_drive_cab',
 'acu.general_management_and_controller.humid_drive_cab',
 'acu.general_management_and_controller.temp_air_inlet_psc',
 'acu.general_management_and_controller.humid_air_inlet_psc',
 'acu.general_management_and_controller.temp_air_outlet_psc',
 'acu.general_management_and_controller.humid_air_outlet_psc',
 'acu.general_management_and_controller.act_power_consum',
 'acu.general_management_and_controller.voltage_phase_1',
 'acu.general_management_and_controller.voltage_phase_2',
 'acu.general_management_and_controller.voltage_phase_3',
 'acu.general_management_and_controller.current_phase_1',
 'acu.general_management_and_controller.current_phase_2',
 'acu.general_management_and_controller.current_phase_3',
 'acu.general_management_and_controller.frequency_phase_1',
 'acu.general_management_and_controller.frequency_phase_2',
 'acu.general_management_and_controller.frequency_phase_3',
 'acu.general_management_and_controller.power_factor',
 'acu.general_management_and_controller.working_counter_system',
 'acu.general_management_and_controller.working_counter_az',
 'acu.general_management_and_controller.working_counter_el',
 'acu.general_management_and_controller.working_counter_fi',

 'acu.azimuth.state',
 'acu.azimuth.axis_bit_status.abs_init_ok',
 'acu.azimuth.axis_bit_status.abs_emergency_stop',
 'acu.azimuth.error_status.err_error_active',
 'acu.azimuth.error_status.err_override',
 'acu.azimuth.error_status.err_power',
 'acu.azimuth.error_status.err_brake',
 'acu.azimuth.error_status.err_mot_overload',
 'acu.azimuth.error_status.err_pos_enc',
 'acu.azimuth.error_status.err_pos_enc_step',
 'acu.azimuth.error_status.err_field_bus',
 'acu.azimuth.error_status.err_lim_err',
 'acu.azimuth.warning_status.wa_param_fault',
 'acu.azimuth.warning_status.wa_rate_mode',
 'acu.azimuth.warning_status.wa_degraded_mode',
 'acu.azimuth.warning_status.wa_override',
 'acu.azimuth.warning_status.wa_brake_open_inaktiv',
 'acu.azimuth.warning_status.wa_mot_warn',
 'acu.azimuth.warning_status.wa_m_max_exceeded',
 'acu.azimuth.warning_status.wa_pos_enc_warn',
 'acu.azimuth.warning_status.wa_stowpins_deployed',

 'acu.azimuth.state',
 'acu.azimuth.p_set',
 'acu.azimuth.p_shape',
 'acu.azimuth.p_act',
 'acu.azimuth.p_enc',
 'acu.azimuth.p_point_corr',
 'acu.azimuth.p_dev',
 'acu.azimuth.p_dev_fil',
 'acu.azimuth.v_shape',
 'acu.azimuth.v_act',
 'acu.azimuth.a_shape',
 'acu.azimuth.motor_1.actual_velocity',
 'acu.azimuth.motor_1.actual_torque',
 'acu.azimuth.motor_1.motor_temperature',
 'acu.azimuth.motor_1.motor_overload',
 'acu.azimuth.motor_2.actual_velocity',
 'acu.azimuth.motor_2.actual_torque',
 'acu.azimuth.motor_2.motor_temperature',
 'acu.azimuth.motor_2.motor_overload',

 'acu.elevation.state',
 'acu.elevation.axis_bit_status.abs_init_ok',
 'acu.elevation.axis_bit_status.abs_emergency_stop',
 'acu.elevation.error_status.err_error_active',
 'acu.elevation.error_status.err_override',
 'acu.elevation.error_status.err_power',
 'acu.elevation.error_status.err_brake',
 'acu.elevation.error_status.err_mot_overload',
 'acu.elevation.error_status.err_pos_enc',
 'acu.elevation.error_status.err_field_bus',
 'acu.elevation.error_status.err_lim_err',
 'acu.elevation.warning_status.wa_param_fault',
 'acu.elevation.warning_status.wa_rate_mode',
 'acu.elevation.warning_status.wa_degraded_mode',
 'acu.elevation.warning_status.wa_override',
 'acu.elevation.warning_status.wa_brake_open_inaktiv',
 'acu.elevation.warning_status.wa_mot_warn',
 'acu.elevation.warning_status.wa_m_max_exceeded',
 'acu.elevation.warning_status.wa_pos_enc_warn',
 'acu.elevation.warning_status.wa_stowpins_deployed',

 'acu.elevation.state',
 'acu.elevation.p_set',
 'acu.elevation.p_shape',
 'acu.elevation.p_act',
 'acu.elevation.p_enc',
 'acu.elevation.p_point_corr',
 'acu.elevation.p_dev',
 'acu.elevation.p_dev_fil',
 'acu.elevation.v_shape',
 'acu.elevation.v_act',
 'acu.elevation.a_shape',
 'acu.elevation.motor_1.actual_velocity',
 'acu.elevation.motor_1.actual_torque',
 'acu.elevation.motor_1.motor_temperature',
 'acu.elevation.motor_1.motor_overload',
 'acu.elevation.motor_2.actual_velocity',
 'acu.elevation.motor_2.actual_torque',
 'acu.elevation.motor_2.motor_temperature',
 'acu.elevation.motor_2.motor_overload',

    
    
 'acu.feed_indexer.state',
 'acu.feed_indexer.axis_bit_status.abs_init_ok',
 'acu.feed_indexer.axis_bit_status.abs_emergency_stop',
 'acu.feed_indexer.error_status.err_error_active',
 'acu.feed_indexer.error_status.err_override',
 'acu.feed_indexer.error_status.err_power',
 'acu.feed_indexer.error_status.err_brake',
 'acu.feed_indexer.error_status.err_mot_overload',
 'acu.feed_indexer.error_status.err_pos_enc',
 'acu.feed_indexer.error_status.err_field_bus',
 'acu.feed_indexer.error_status.err_lim_err',
 'acu.feed_indexer.warning_status.wa_param_fault',
 'acu.feed_indexer.warning_status.wa_rate_mode',
 'acu.feed_indexer.warning_status.wa_degraded_mode',
 'acu.feed_indexer.warning_status.wa_override',
 'acu.feed_indexer.warning_status.wa_brake_open_inaktiv',
 'acu.feed_indexer.warning_status.wa_mot_warn',
 'acu.feed_indexer.warning_status.wa_m_max_exceeded',
 'acu.feed_indexer.warning_status.wa_pos_enc_warn',
 'acu.feed_indexer.warning_status.wa_stowpins_deployed',

 'acu.feed_indexer.state',
 'acu.feed_indexer.p_set',
 'acu.feed_indexer.p_shape',
 'acu.feed_indexer.p_act',
 'acu.feed_indexer.p_enc',
 'acu.feed_indexer.p_point_corr',
 'acu.feed_indexer.p_dev',
 'acu.feed_indexer.p_dev_fil',
 'acu.feed_indexer.v_shape',
 'acu.feed_indexer.v_act',
 'acu.feed_indexer.a_shape',
 'acu.feed_indexer.motor_1.actual_velocity',
 'acu.feed_indexer.motor_1.actual_torque',
 'acu.feed_indexer.motor_1.motor_temperature',
 'acu.feed_indexer.motor_1.motor_overload',
 'acu.feed_indexer.motor_2.actual_velocity',
 'acu.feed_indexer.motor_2.actual_torque',
 'acu.feed_indexer.motor_2.motor_temperature',
 'acu.feed_indexer.motor_2.motor_overload',

 'acu.pointing.act_amb_temp_1',
 'acu.pointing.act_amb_temp_2',
 'acu.pointing.act_amb_temp_3',
 'acu.pointing.amb_temp_corr_val_az',
 'acu.pointing.amb_temp_corr_val_el',
 'acu.pointing.amb_temp_corr_filter_constant',
 'acu.pointing.incl_signal_x_raw',
 'acu.pointing.incl_signal_y_raw',
 'acu.pointing.incl_signal_x_deg',
 'acu.pointing.incl_signal_y_deg',
 'acu.pointing.incl_signal_x_filtered',
 'acu.pointing.incl_signal_y_filtered',
 'acu.pointing.incl_signal_x_corrected',
 'acu.pointing.incl_signal_y_corrected',
 'acu.pointing.incl_temp',
 'acu.pointing.incl_corr_val_az',
 'acu.pointing.incl_corr_val_el',
 'acu.pointing.incl_filter_constant',
 'acu.pointing.p1',
 'acu.pointing.p2',
 'acu.pointing.p3',
 'acu.pointing.p4',
 'acu.pointing.p5',
 'acu.pointing.p6',
 'acu.pointing.p7',
 'acu.pointing.p8',
 'acu.pointing.p9',
 'acu.pointing.pm_corr_val_az',
 'acu.pointing.pm_corr_val_el',
 'acu.pointing.point_corr_az',
 'acu.pointing.point_corr_el',
    
 'acu.time.act_time_source',
 'acu.time.bit_status.time_init_ok',
 'acu.time.bit_status.not_used_1',
 'acu.time.bit_status.time_ptp_not_sync',
 'acu.time.internal_time',
 'acu.time.external_ptp',
 'acu.time.offset',

 'acu.command_arbiter.act_authority',
    
 'acu.safety_controller.state',
 'acu.safety_controller.safety_status_bs.abs_init',
 'acu.safety_controller.safety_status_bs.safety_system_error',
 'acu.safety_controller.safety_status_bs.safety_system_run',
 'acu.safety_controller.safety_status_bs.door_switch_status_ped',
#  'acu.safety_controller.safety_status_bs.door_switch_status_psc',
 'acu.safety_controller.safety_status_bs.lockout_azimuth',
 'acu.safety_controller.safety_status_bs.lockout_elevation',
 'acu.safety_controller.safety_status_bs.lockout_feedindexer',
 'acu.safety_controller.safety_status_bs.e_stop_hhd_lockout_box',
 'acu.safety_controller.safety_status_bs.e_stop_feed_indexer',
 'acu.safety_controller.safety_status_bs.sto_az',
 'acu.safety_controller.safety_status_bs.sto_el',
 'acu.safety_controller.safety_status_bs.sto_fi',
 'acu.safety_controller.safety_status_bs.em_limit_up_az',
 'acu.safety_controller.safety_status_bs.em_limit_dn_az',
 'acu.safety_controller.safety_status_bs.em_limit_up_el',
 'acu.safety_controller.safety_status_bs.em_limit_dn_el',
 'acu.safety_controller.safety_status_bs.em_limit_up_fi',
 'acu.safety_controller.safety_status_bs.em_limit_dn_fi',

 'acu.stow_pin_controller.azimuth_status',
 'acu.stow_pin_controller.elevation_status',
 
 'acu.ambient_temp_correction_config.ambient_factor_az_band_1',
 'acu.ambient_temp_correction_config.ambient_factor_az_band_2',
 'acu.ambient_temp_correction_config.ambient_factor_az_band_3',
 'acu.ambient_temp_correction_config.ambient_factor_az_band_4',
 'acu.ambient_temp_correction_config.ambient_factor_az_band_5a',
 'acu.ambient_temp_correction_config.ambient_factor_az_band_5b',
 'acu.ambient_temp_correction_config.ambient_factor_az_band_5c',
 'acu.ambient_temp_correction_config.ambient_factor_az_band_8',
 'acu.ambient_temp_correction_config.ambient_factor_az_band_9',
 'acu.ambient_temp_correction_config.ambient_factor_az_band_10',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_1',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_2',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_3',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_4',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_5a',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_5b',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_5c',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_8',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_9',
 'acu.ambient_temp_correction_config.ambient_factor_el_band_10'
]


channels_normal =  [
 'acu.actual_timestamp',
 'acu.general_management_and_controller.ds_software_version',
 'acu.general_management_and_controller.state',

 'acu.general_management_and_controller.bit_status.hhd_connected',
 'acu.general_management_and_controller.bit_status.on_source',

 'acu.general_management_and_controller.error_status.az_error',
 'acu.general_management_and_controller.error_status.el_error',
 'acu.general_management_and_controller.error_status.fi_error',
 'acu.general_management_and_controller.error_status.stp_error',
 'acu.general_management_and_controller.error_status.saf_error',
 'acu.general_management_and_controller.error_status.tim_error',
 'acu.general_management_and_controller.error_status.cmd_error',

 'acu.general_management_and_controller.p_set_az',
 'acu.general_management_and_controller.p_act_az',
 'acu.general_management_and_controller.v_act_az',
 'acu.general_management_and_controller.p_point_corr_az',
 'acu.general_management_and_controller.p_set_el',
 'acu.general_management_and_controller.p_act_el',
 'acu.general_management_and_controller.v_act_el',
 'acu.general_management_and_controller.p_point_corr_el',
 'acu.general_management_and_controller.feed_indexer_pos',
 'acu.general_management_and_controller.on_source_deviation_rms',
 
 'acu.general_management_and_controller.temp_emisc',
 'acu.general_management_and_controller.temp_drive_cab',
 'acu.general_management_and_controller.humid_drive_cab',
 'acu.general_management_and_controller.temp_air_inlet_psc',
 'acu.general_management_and_controller.humid_air_inlet_psc',
 'acu.general_management_and_controller.temp_air_outlet_psc',
 'acu.general_management_and_controller.humid_air_outlet_psc',
 'acu.general_management_and_controller.act_power_consum',

 'acu.azimuth.state',
 'acu.azimuth.p_set',
 'acu.azimuth.p_shape',
 'acu.azimuth.p_act',
 'acu.azimuth.p_enc',
 'acu.azimuth.p_point_corr',
 'acu.azimuth.p_dev',
 'acu.azimuth.p_dev_fil',
 'acu.azimuth.v_shape',
 'acu.azimuth.v_act',
 'acu.azimuth.a_shape',
 'acu.azimuth.motor_1.actual_velocity',
 'acu.azimuth.motor_1.actual_torque',
 'acu.azimuth.motor_1.motor_temperature',
 'acu.azimuth.motor_1.motor_overload',
 'acu.azimuth.motor_2.actual_velocity',
 'acu.azimuth.motor_2.actual_torque',
 'acu.azimuth.motor_2.motor_temperature',
 'acu.azimuth.motor_2.motor_overload',

 'acu.elevation.state',
 'acu.elevation.p_set',
 'acu.elevation.p_shape',
 'acu.elevation.p_act',
 'acu.elevation.p_enc',
 'acu.elevation.p_point_corr',
 'acu.elevation.p_dev',
 'acu.elevation.p_dev_fil',
 'acu.elevation.v_shape',
 'acu.elevation.v_act',
 'acu.elevation.a_shape',
 'acu.elevation.motor_1.actual_velocity',
 'acu.elevation.motor_1.actual_torque',
 'acu.elevation.motor_1.motor_temperature',
 'acu.elevation.motor_1.motor_overload',
 'acu.elevation.motor_2.actual_velocity',
 'acu.elevation.motor_2.actual_torque',
 'acu.elevation.motor_2.motor_temperature',
 'acu.elevation.motor_2.motor_overload',    
    
 'acu.feed_indexer.state',
 'acu.feed_indexer.p_set',
 'acu.feed_indexer.p_shape',
 'acu.feed_indexer.p_act',
 'acu.feed_indexer.p_enc',
 'acu.feed_indexer.p_point_corr',
 'acu.feed_indexer.p_dev',
 'acu.feed_indexer.p_dev_fil',
 'acu.feed_indexer.v_shape',
 'acu.feed_indexer.v_act',
 'acu.feed_indexer.a_shape',
 
 'acu.pointing.act_amb_temp_1',
 'acu.pointing.act_amb_temp_2',
 'acu.pointing.act_amb_temp_3',
 'acu.pointing.amb_temp_corr_val_az',
 'acu.pointing.amb_temp_corr_val_el',
 'acu.pointing.amb_temp_corr_filter_constant',
 'acu.pointing.incl_signal_x_raw',
 'acu.pointing.incl_signal_y_raw',
 'acu.pointing.incl_signal_x_deg',
 'acu.pointing.incl_signal_y_deg',
 'acu.pointing.incl_signal_x_filtered',
 'acu.pointing.incl_signal_y_filtered',
 'acu.pointing.incl_signal_x_corrected',
 'acu.pointing.incl_signal_y_corrected',
 'acu.pointing.incl_temp',
 'acu.pointing.incl_corr_val_az',
 'acu.pointing.incl_corr_val_el',
 'acu.pointing.incl_filter_constant',

 'acu.pointing.pm_corr_val_az',
 'acu.pointing.pm_corr_val_el',
 'acu.pointing.point_corr_az',
 'acu.pointing.point_corr_el',
    
 'acu.time.act_time_source',
 'acu.time.bit_status.time_init_ok',
 'acu.time.bit_status.time_ptp_not_sync',
 'acu.time.internal_time',
 'acu.time.external_ptp',
 'acu.time.offset',

 'acu.command_arbiter.act_authority',
    
 'acu.safety_controller.state',

 'acu.stow_pin_controller.azimuth_status',
 'acu.stow_pin_controller.elevation_status'
]

channels_general =  [
 'acu.general_management_and_controller.ds_software_version',
 'acu.general_management_and_controller.state',

 'acu.general_management_and_controller.bit_status.hhd_connected',

 'acu.general_management_and_controller.p_set_az',
 'acu.general_management_and_controller.p_act_az',
 'acu.general_management_and_controller.v_act_az',
 'acu.general_management_and_controller.p_point_corr_az',
 'acu.general_management_and_controller.p_set_el',
 'acu.general_management_and_controller.p_act_el',
 'acu.general_management_and_controller.v_act_el',
 'acu.general_management_and_controller.p_point_corr_el',
 'acu.general_management_and_controller.feed_indexer_pos',
 
 'acu.general_management_and_controller.temp_emisc',
 'acu.general_management_and_controller.temp_drive_cab',
 'acu.general_management_and_controller.humid_drive_cab',
 'acu.general_management_and_controller.temp_air_inlet_psc',
 'acu.general_management_and_controller.humid_air_inlet_psc',
 'acu.general_management_and_controller.temp_air_outlet_psc',
 'acu.general_management_and_controller.humid_air_outlet_psc',
 'acu.general_management_and_controller.act_power_consum',
]

channels_reduced =  [
 'acu.actual_timestamp',
 'acu.general_management_and_controller.ds_software_version',
 'acu.general_management_and_controller.state',

 'acu.general_management_and_controller.bit_status.hhd_connected',
 'acu.general_management_and_controller.bit_status.on_source',

 'acu.general_management_and_controller.temp_emisc',
 'acu.general_management_and_controller.temp_drive_cab',
 'acu.general_management_and_controller.humid_drive_cab',
 'acu.general_management_and_controller.temp_air_inlet_psc',
 'acu.general_management_and_controller.humid_air_inlet_psc',
 'acu.general_management_and_controller.temp_air_outlet_psc',
 'acu.general_management_and_controller.humid_air_outlet_psc',
 'acu.general_management_and_controller.act_power_consum',

 'acu.azimuth.state',
 'acu.azimuth.p_set',
 'acu.azimuth.p_shape',
 'acu.azimuth.p_act',
 'acu.azimuth.p_point_corr',
 'acu.azimuth.v_shape',
 'acu.azimuth.v_act',

 'acu.elevation.state',
 'acu.elevation.p_set',
 'acu.elevation.p_shape',
 'acu.elevation.p_act',
 'acu.elevation.p_point_corr',
 'acu.elevation.v_shape',
 'acu.elevation.v_act', 
    
 'acu.feed_indexer.state',
 'acu.feed_indexer.p_set',
 'acu.feed_indexer.p_shape',
 'acu.feed_indexer.p_act',
 'acu.feed_indexer.p_point_corr',
 'acu.feed_indexer.v_shape',
 'acu.feed_indexer.v_act',
 
 'acu.pointing.act_amb_temp_1',
 'acu.pointing.act_amb_temp_2',
 'acu.pointing.act_amb_temp_3',
 'acu.pointing.amb_temp_corr_val_az',
 'acu.pointing.amb_temp_corr_val_el',
 'acu.pointing.incl_signal_x_deg',
 'acu.pointing.incl_signal_y_deg',
 'acu.pointing.incl_signal_x_filtered',
 'acu.pointing.incl_signal_y_filtered',
 'acu.pointing.incl_signal_x_corrected',
 'acu.pointing.incl_signal_y_corrected',
 'acu.pointing.incl_temp',
 'acu.pointing.incl_corr_val_az',
 'acu.pointing.incl_corr_val_el',

 'acu.pointing.pm_corr_val_az',
 'acu.pointing.pm_corr_val_el',
 'acu.pointing.point_corr_az',
 'acu.pointing.point_corr_el',
    
 'acu.time.act_time_source',
 'acu.time.bit_status.time_init_ok',
 'acu.time.bit_status.time_ptp_not_sync',
 'acu.time.internal_time',
 'acu.time.external_ptp',
 'acu.time.offset',

 'acu.command_arbiter.act_authority',
    
 'acu.safety_controller.state',

 'acu.stow_pin_controller.azimuth_status',
 'acu.stow_pin_controller.elevation_status'
]


channels_small =  ['acu.actual_timestamp',
 'acu.general_management_and_controller.state',
 'acu.general_management_and_controller.p_act_az',
 'acu.general_management_and_controller.v_act_az',
 'acu.general_management_and_controller.p_point_corr_az',
 'acu.general_management_and_controller.p_act_el',
 'acu.general_management_and_controller.v_act_el',
 'acu.general_management_and_controller.p_point_corr_az',
]


channels_hn_feed_indexer_sensors=[
'acu.time.act_time_source',
'acu.time.internal_time',
'acu.time.external_ptp',
'acu.general_management_and_controller.state',
'acu.general_management_and_controller.feed_indexer_pos',
'acu.azimuth.state',
'acu.azimuth.p_set',
'acu.azimuth.p_act',
'acu.azimuth.v_act',
'acu.elevation.state',
'acu.elevation.p_set',
'acu.elevation.p_act',
'acu.elevation.v_act',
'acu.feed_indexer.state',
'acu.feed_indexer.p_set',
'acu.feed_indexer.p_shape',
'acu.feed_indexer.p_act',
'acu.feed_indexer.v_shape',
'acu.feed_indexer.v_act',
'acu.feed_indexer.motor_1.actual_velocity',
'acu.feed_indexer.motor_2.actual_velocity',
'acu.feed_indexer.motor_1.actual_torque',
'acu.feed_indexer.motor_2.actual_torque',
'acu.general_management_and_controller.act_power_consum',
'acu.general_management_and_controller.power_factor',
'acu.general_management_and_controller.voltage_phase_1',
'acu.general_management_and_controller.voltage_phase_2',
'acu.general_management_and_controller.voltage_phase_3',
'acu.general_management_and_controller.current_phase_1',
'acu.general_management_and_controller.current_phase_2',
'acu.general_management_and_controller.current_phase_3'
]

#hn_tilt_sensors is equivalent to "Servo performance"
channels_hn_tilt_sensors=[
'acu.time.act_time_source',
'acu.time.internal_time',
'acu.time.external_ptp',
'acu.general_management_and_controller.state',
'acu.general_management_and_controller.feed_indexer_pos',
'acu.azimuth.state',
'acu.azimuth.p_set',
'acu.azimuth.p_act',
'acu.azimuth.v_act',
'acu.elevation.state',
'acu.elevation.p_set',
'acu.elevation.p_act',
'acu.elevation.v_act',
'acu.general_management_and_controller.act_power_consum',
'acu.general_management_and_controller.power_factor',
'acu.general_management_and_controller.voltage_phase_1',
'acu.general_management_and_controller.voltage_phase_2',
'acu.general_management_and_controller.voltage_phase_3',
'acu.general_management_and_controller.current_phase_1',
'acu.general_management_and_controller.current_phase_2',
'acu.general_management_and_controller.current_phase_3',
'acu.pointing.act_amb_temp_1',
'acu.pointing.act_amb_temp_2',
'acu.pointing.act_amb_temp_3',
'acu.general_management_and_controller.temp_air_inlet_psc',
'acu.general_management_and_controller.temp_air_outlet_psc',
'acu.pointing.incl_signal_x_raw',
'acu.pointing.incl_signal_x_deg',
'acu.pointing.incl_signal_x_filtered',
'acu.pointing.incl_signal_x_corrected',
'acu.pointing.incl_signal_y_raw',
'acu.pointing.incl_signal_y_deg',
'acu.pointing.incl_signal_y_filtered',
'acu.pointing.incl_signal_y_corrected',
'acu.pointing.incl_temp',
'acu.pointing.incl_corr_val_az',
'acu.pointing.incl_corr_val_el'
]

if __name__ == "__main__":
    for l in channels_detailed:
        print(l)